==> qtjambi-qt3drender-debuginfo-windows-x64-5.15.17.jar: sources/QtJambi3DRender/QRenderCaptureReply_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <Qt3DRender/qrendercapture.h>
#include <QtCore/QVariant>
#include <QtGui/qimage.h>
#include <QtCore/qobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/QList>
#include <QtCore/qcoreevent.h>
#include <QtCore/qtimer.h>
#include <QtCore/qregexp.h>
#include <QtCore/qthread.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qmetaobject.h>
#include <QtCore/qbytearray.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_Qt3DRender_QRenderCaptureReply_0(){
    static int result = QMetaMethod::fromSignal(&Qt3DRender::QRenderCaptureReply::completeChanged).methodIndex();
    return result;
}


int __signal_method_indexes_Qt3DRender_QRenderCaptureReply_1(){
    static int result = QMetaMethod::fromSignal(&Qt3DRender::QRenderCaptureReply::completed).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DRender::QRenderCaptureReply::captureId()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QRenderCaptureReply_captureId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DRender::QRenderCaptureReply *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DRender::QRenderCaptureReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QRenderCaptureReply::captureId()const", __qt_this)
        __java_return_value = __qt_this->captureId();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DRender::QRenderCaptureReply::image()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QRenderCaptureReply_image_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DRender::QRenderCaptureReply *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DRender::QRenderCaptureReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QRenderCaptureReply::image()const", __qt_this)
        QImage __qt_return_value = __qt_this->image();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DRender::QRenderCaptureReply::isComplete()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QRenderCaptureReply_isComplete_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DRender::QRenderCaptureReply *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DRender::QRenderCaptureReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QRenderCaptureReply::isComplete()const", __qt_this)
        __java_return_value = __qt_this->isComplete();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DRender::QRenderCaptureReply::saveImage(QString)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QRenderCaptureReply_saveImage_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring fileName0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DRender::QRenderCaptureReply *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DRender::QRenderCaptureReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QRenderCaptureReply::saveImage(QString)const", __qt_this)
        QString  __qt_fileName0 = qtjambi_cast<QString >(__jni_env, fileName0);
        __java_return_value = __qt_this->saveImage(__qt_fileName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DRender::QRenderCaptureReply::saveToFile(QString)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QRenderCaptureReply_saveToFile_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring fileName0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const Qt3DRender::QRenderCaptureReply *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DRender::QRenderCaptureReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QRenderCaptureReply::saveToFile(QString)const", __qt_this)
        QString  __qt_fileName0 = qtjambi_cast<QString >(__jni_env, fileName0);
        __qt_this->saveToFile(__qt_fileName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DRender_QRenderCaptureReply(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<Qt3DRender::QRenderCaptureReply>("Qt3DRender::QRenderCaptureReply", "io/qt/qt3d/render/QRenderCaptureReply");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, Qt3DRender::QRenderCaptureReply::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "completeChanged", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_Qt3DRender_QRenderCaptureReply_0),
                SignalMetaInfo(/* 1 */ "completed", "Lio/qt/core/QObject$Signal0;", 0, __signal_method_indexes_Qt3DRender_QRenderCaptureReply_1)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_Qt3DRender_QRenderCaptureReply_0()){ // completeChanged(bool isComplete)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(QMetaType::Bool);
                    return true;
                }
                if(methodIndex==__signal_method_indexes_Qt3DRender_QRenderCaptureReply_1()){ // completed()
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==Qt3DRender::QRenderCaptureReply::staticMetaObject.indexOfMethod("saveImage(QString)const")){
                    infos << ParameterInfo(QMetaType::Bool);
                    infos << ParameterInfo(QMetaType::QString);
                    return true;
                }
                if(methodIndex==Qt3DRender::QRenderCaptureReply::staticMetaObject.indexOfMethod("saveToFile(QString)const")){
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(QMetaType::QString);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qt3drender-debuginfo-windows-x64-6.5.3.jar: sources/QtJambi3DRender/QRenderCaptureReply_shell.cpp <==
#include <QtCore/QtGlobal>
#include <Qt3DRender/qrendercapture.h>
#include <QtCore/QVariant>
#include <QtGui/qimage.h>
#include <QtCore/qobject.h>
#include <QtCore/QList>
#include <QtCore/qtimer.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qbindingstorage.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qproperty.h>
#include <QtCore/qthread.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qbytearray.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_Qt3DRender_QRenderCaptureReply_0(){
    static int result = QMetaMethod::fromSignal(&Qt3DRender::QRenderCaptureReply::completed).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DRender::QRenderCaptureReply::captureId()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QRenderCaptureReply_captureId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DRender::QRenderCaptureReply *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DRender::QRenderCaptureReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QRenderCaptureReply::captureId()const", __qt_this)
        __java_return_value = __qt_this->captureId();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DRender::QRenderCaptureReply::image()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QRenderCaptureReply_image_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DRender::QRenderCaptureReply *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DRender::QRenderCaptureReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QRenderCaptureReply::image()const", __qt_this)
        QImage __qt_return_value = __qt_this->image();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DRender::QRenderCaptureReply::isComplete()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QRenderCaptureReply_isComplete_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DRender::QRenderCaptureReply *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DRender::QRenderCaptureReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QRenderCaptureReply::isComplete()const", __qt_this)
        __java_return_value = __qt_this->isComplete();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DRender::QRenderCaptureReply::saveImage(QString)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QRenderCaptureReply_saveImage_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring fileName0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DRender::QRenderCaptureReply *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DRender::QRenderCaptureReply>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QRenderCaptureReply::saveImage(QString)const", __qt_this)
        QString  __qt_fileName0 = qtjambi_cast<QString >(__jni_env, fileName0);
        __java_return_value = __qt_this->saveImage(__qt_fileName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DRender_QRenderCaptureReply(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<Qt3DRender::QRenderCaptureReply>("Qt3DRender::QRenderCaptureReply", "io/qt/qt3d/render/QRenderCaptureReply");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, Qt3DRender::QRenderCaptureReply::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "completed", "Lio/qt/core/QObject$Signal0;", 0, __signal_method_indexes_Qt3DRender_QRenderCaptureReply_0)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_Qt3DRender_QRenderCaptureReply_0()){ // completed()
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==Qt3DRender::QRenderCaptureReply::staticMetaObject.indexOfMethod("saveImage(QString)const")){
                    infos << ParameterInfo(QMetaType::Bool);
                    infos << ParameterInfo(QMetaType::QString);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
